==> jmb.async-0.1.tar.gz: jmb.async-0.1/jmb/async/dashboard.py <==
# -*- coding: utf-8 -*-

import datetime

from django.utils.translation import ugettext_lazy as _
from django.db import connections
from django.db.models import Sum
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.async.models import Task
from jmb.core.admin import dashboard as jmb_dashboard

class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs =  {
            'title': "Task",
            'display': "tabs",
            'children': [
                CustomModule(
                    title='Today Task',
                    order_by='-date_create',
                    limit=None,
                    extra_filters={'date_create__gte': today},
                ),
                Models(),
                OtherModels(),
#                TaskSettings(),
                Permissions(),
            ]
        }
        super(DefaultDashboard, self).__init__(**kwargs)

class TaskDashboard(modules.Group):
    def __init__(self, **kwargs):

        today = datetime.date.today()
        kwargs =  {
            'title': "Task",
            'display': "tabs",
            'children': [
                Models(),
                OtherModels(),
#                Settings(),
                Permissions(),
            ]
        }
        super(TaskDashboard, self).__init__(**kwargs)

class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Main Models"),
            'models': ('jmb.async.models.Task',),
        }
        super(Models, self).__init__(**kwargs)

class OtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Others"),
            'models': (),
        }
        super(OtherModels, self).__init__(**kwargs)

# class Settings(modules.ModelList):
#     def __init__(self, **kwargs):
#         kwargs =  {
#             'title': _("Settings"),
#             'models':['jmb.async.models.Settings',],
#             }
#         super(Settings, self).__init__(**kwargs)

class Permissions(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Permissions"),
            'models':['jmb.async.models.TaskPermissions',],
        }
        super(Permissions, self).__init__(**kwargs)

class CustomModule(modules.DashboardModule):
    """Esempio di modulo che produce contentuto generico
    """
    def __init__(self, title, template='admin_tools/async/custom.html',
                 order_by=None, limit=10, qs=Task.objects.all(), extra_filters={},
                 children=None, **kwargs):
        self.order_by = order_by
        self.template = template
        self.qs = qs
        self.extra_filters = extra_filters
        self.limit = limit
        self.custom_children = children

        kwargs =  {
            'title': title,
            'template': self.template,
            'children': self.custom_children
        }
        super(CustomModule, self).__init__(**kwargs)

    def init_with_context(self, context):
        request = context['request']
        if self.custom_children is None:
            qs = self.qs
            if self.extra_filters: qs = qs.filter(**self.extra_filters)
            if self.order_by: qs = qs.order_by(self.order_by)
            if self.limit: qs = qs[:self.limit]
            self.children = qs


class DefaultAppDashboard(AppIndexDashboard):
#    class Media:
#        css = ('office_thunder/css/dashboard.css',)
#
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 2

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin 
jmb_dashboard.register_group(TaskDashboard, 'jmb.async')
# Used in /admin/Task
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.async')

==> jmb.async-0.3.1.tar.gz: jmb.async-0.3.1/jmb/async/dashboard.py <==
# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _
import admin_tools
from admin_tools.dashboard import modules, AppIndexDashboard

from jmb.async.models import Task
from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs = {
            'title': "Task",
            'display': "tabs",
            'children': [
                Models(),
            ]
        }
        super(DefaultDashboard, self).__init__(**kwargs)


class TaskDashboard(modules.Group):
    def __init__(self, **kwargs):

        kwargs = {
            'title': "Task",
            'display': "tabs",
            'children': [
                Models(),
            ]
        }
        super(TaskDashboard, self).__init__(**kwargs)


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs =  {
            'title': _("Main Models"),
            'models': ('jmb.async.models.*',),
        }
        super(Models, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin 
jmb_dashboard.register_group(TaskDashboard, 'jmb.async')
# Used in /admin/Task
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.async')
